@@ -1,7 +1,7 @@
 #ifndef __GDICT_APPLET_H_
 #define __GDICT_APPLET_H_
 
-/* $Id: gdict-applet.h,v 1.4 2001/04/19 01:15:12 hovinen Exp $ */
+/* $Id: gdict-applet.h,v 1.9 2004/02/12 09:14:34 dsmit Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -12,6 +12,8 @@
  *  GDict panel applet
  *
  */
+ 
+#include <panel-applet.h>
 
 /* This structure contains the internal state of the gdict applet.
  * Everything the functions and signal handlers need to be able to
@@ -19,16 +21,14 @@
 typedef struct _GDictApplet {
 	GtkWidget *applet_widget;
 	GtkWidget *button_widget;
-	GtkWidget *vbox_widget;
+	GtkWidget *box;
 	GtkWidget *entry_widget;
-	GtkWidget *handlebox_widget;
+	GtkWidget *about_dialog;
+	PanelAppletOrient orient;
 	gboolean handle;
+	gint panel_size;
 } GDictApplet;
 
-extern gboolean gdict_applet_toggle;
-
-extern GDictApplet * gdict_applet_create (void);
-extern void gdict_applet_delete (GDictApplet * applet);
 
 
 #endif /* __GDICT_APPLET_H_ */
