@@ -25,16 +25,11 @@
  *
  */
 
-#define ICON_SIZE 24.0
 #define GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE 48
 #define GNOME_SEARCH_TOOL_STOCK "panel-searchtool"
+#define GNOME_SEARCH_TOOL_REFRESH_DURATION  50000
 #define LEFT_LABEL_SPACING "     "
 
-#define DEFAULT_ANIMATION_WIDTH   48
-#define DEFAULT_ANIMATION_HEIGHT  48
-#define DEFAULT_ANIMATION_FRAME    2
-#define TOTAL_ANIMATION_FRAMES     3
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -51,12 +46,13 @@
 #include "gsearchtool-support.h"
 #include "gsearchtool-callbacks.h"
 #include "gsearchtool-alert-dialog.h"
+#include "gsearchtool-spinner.h"
 
 #include <string.h>
 #include <unistd.h>
 #include <signal.h>
 #include <libbonobo.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
@@ -328,6 +324,9 @@ build_search_command (void)
 		if ((disable_quick_search != TRUE) && (locate != NULL) 
 		    && (is_path_in_home_folder (look_in_folder_locale) != TRUE) 
 		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)
+		    && (is_path_in_proc_folder (look_in_folder_locale) != TRUE) 
+		    && (is_path_in_dev_folder (look_in_folder_locale) != TRUE)
+		    && (is_path_in_var_folder (look_in_folder_locale) != TRUE)
 		    && (is_path_in_tmp_folder (look_in_folder_locale) != TRUE)) {	
 			g_string_append_printf (command, "%s %s '%s*%s'", 
 						locate,
@@ -447,46 +446,24 @@ add_file_to_search_results (const gchar 	*file,
 			    GtkListStore 	*store, 
 			    GtkTreeIter 	*iter)
 {					
-	gchar *mime_type = gnome_vfs_get_mime_type (file);
-	gchar *description = get_file_type_with_mime_type (file, mime_type);
-	gchar *icon_path = get_file_icon_with_mime_type (file, mime_type);
-	GnomeVFSFileInfo *vfs_file_info = gnome_vfs_file_info_new ();
-	GdkPixbuf *pixbuf = NULL;
+	const char *mime_type; 
+	const char *description;
+	GdkPixbuf *pixbuf;
+	GnomeVFSFileInfo *vfs_file_info;
 	gchar *readable_size, *readable_date;
 	gchar *utf8_base_name, *utf8_dir_name;
 	gchar *base_name, *dir_name;
 	
+	mime_type = gnome_vfs_get_file_mime_type (file, NULL, FALSE);
+	 
+	description = get_file_type_for_mime_type (file, mime_type);
+	pixbuf = get_file_pixbuf_for_mime_type (file, mime_type);
+	
 	if (gtk_tree_view_get_headers_visible (GTK_TREE_VIEW(interface.tree)) == FALSE) {
 		gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(interface.tree), TRUE);
 	}
 	
-	if (icon_path != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
-	}
-	
-	if (pixbuf != NULL) {
-		GdkPixbuf *scaled;
-		int        new_w, new_h;
-		int        w, h;
-		double     factor;
-
-		/* scale keeping aspect ratio. */
-
-		w = gdk_pixbuf_get_width (pixbuf);
-		h = gdk_pixbuf_get_height (pixbuf);
-			
-		factor = MIN (ICON_SIZE / w, ICON_SIZE / h);
-		new_w  = MAX ((int) (factor * w), 1);
-		new_h  = MAX ((int) (factor * h), 1);
-			
-		scaled = gdk_pixbuf_scale_simple (pixbuf,
-						  new_w,
-						  new_h,
-						  GDK_INTERP_BILINEAR);
-						  				  
-		g_object_unref (G_OBJECT (pixbuf));
-		pixbuf = scaled;       	
-	}
+	vfs_file_info = gnome_vfs_file_info_new ();
 	gnome_vfs_get_file_info (file, vfs_file_info, GNOME_VFS_FILE_INFO_DEFAULT);
 	readable_size = gnome_vfs_format_file_size_for_display (vfs_file_info->size);
 	readable_date = get_readable_date (vfs_file_info->mtime);
@@ -504,23 +481,17 @@ add_file_to_search_results (const gchar 	*file,
 			    COLUMN_PATH, utf8_dir_name,
 			    COLUMN_READABLE_SIZE, readable_size,
 			    COLUMN_SIZE, (-1) * (gdouble) vfs_file_info->size,
-			    COLUMN_TYPE, description,
+			    COLUMN_TYPE, (description != NULL) ? description : mime_type,
 			    COLUMN_READABLE_DATE, readable_date,
 			    COLUMN_DATE, (-1) * (gdouble) vfs_file_info->mtime,
 			    COLUMN_NO_FILES_FOUND, FALSE,
 			    -1);
 
-	if (pixbuf != NULL) {
-		g_object_unref (G_OBJECT(pixbuf));
-	}
-
 	gnome_vfs_file_info_unref (vfs_file_info);
 	g_free (base_name);
 	g_free (dir_name);
-	g_free (mime_type);
 	g_free (utf8_base_name);
 	g_free (utf8_dir_name);
-	g_free (icon_path); 
 	g_free (readable_size);
 	g_free (readable_date);
 }
@@ -567,12 +538,14 @@ update_search_counts (void)
 		add_no_files_found_message (interface.model, &interface.iter);
 	}
 	else {
-		title_bar_string = ngettext ("%d File Found",
-					     "%d Files Found",
-					     total_files);
-		message_string = ngettext ("%d file found",
-					   "%d files found",
-					   total_files);
+		title_bar_string = g_strdup_printf (ngettext ("%d File Found",
+					                      "%d Files Found",
+					                      total_files),
+						    total_files);
+		message_string = g_strdup_printf (ngettext ("%d file found",
+					                    "%d files found",
+					                    total_files),
+						  total_files);
 	}
 
 	if (strlen (stopped_string) > 0) {
@@ -919,69 +892,6 @@ get_desktop_item_name (void)
 	return g_string_free (gs, FALSE);
 }
 
-static gboolean
-setup_animation_image (void)
-{
-	gint	   width  = 0;
-	gint	   height = 0;
-	GError     *error = NULL;
-
-	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
-
-	interface.pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gnome-search-tool/gnome-search-tool-animation.png",
-	                                             &error);
-	
-	if (error) {
-		g_warning (_("The animation file is missing or invalid: %s"), error->message);		
-		g_error_free (error);
-		gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), 0, 0);
-		return FALSE;
-	}
-
-	width  = gdk_pixbuf_get_width (interface.pixbuf); 
-	height = gdk_pixbuf_get_height (interface.pixbuf); 
-
-	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), width / TOTAL_ANIMATION_FRAMES, height);
-	gtk_widget_queue_draw (interface.drawing_area); 
-
-	return TRUE;
-}
-
-static gboolean
-animation_expose_event_cb (GtkWidget       *widget,
-                           GdkEventExpose  *event,
-                           gpointer        *data)
-{
-	gint width  = 0;
-	gint height = 0;
-
-	if (interface.pixbuf == NULL) {
-		return FALSE;
-	}
-
-	gdk_window_clear_area (widget->window,
-	                       event->area.x, event->area.y,
-	                       event->area.width, event->area.height);
-
-	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], &event->area); 
-
-	width  = gdk_pixbuf_get_width (interface.pixbuf); 
-	height = gdk_pixbuf_get_height (interface.pixbuf); 
-
-	gdk_pixbuf_render_to_drawable_alpha (interface.pixbuf,
-	                                     GDK_DRAWABLE (widget->window),
-	                                     (width * interface.current_animation_frame) / TOTAL_ANIMATION_FRAMES, 0, 
-	                                     0, 0,
-	                                     width / TOTAL_ANIMATION_FRAMES, height,
-	                                     GDK_PIXBUF_ALPHA_FULL, 255,
-	                                     GDK_RGB_DITHER_MAX,
-	                                     0, 0);
-
-	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], NULL);
-
-        return FALSE;
-}
-
 static void
 start_animation (void)
 {
@@ -991,7 +901,7 @@ start_animation (void)
 	gtk_window_set_title (GTK_WINDOW (interface.main_window), title);
 	
 	gtk_label_set_text (GTK_LABEL (interface.results_label), "");
-	search_command.animation_timeout = g_timeout_add (250, update_animation_timeout_cb, NULL);
+	gsearch_spinner_start (GSEARCH_SPINNER (interface.spinner));
 	
 	g_free (title);
 } 
@@ -999,34 +909,9 @@ start_animation (void)
 static void
 stop_animation (void)
 {
-	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
-	g_source_remove (search_command.animation_timeout);
-	gtk_widget_queue_draw (interface.drawing_area);
+	gsearch_spinner_stop (GSEARCH_SPINNER (interface.spinner));
 } 
 
-gboolean
-update_animation_timeout_cb (gpointer data)
-{
-	static gboolean in_forward_progress = TRUE;
-	
-	if (in_forward_progress) {
-		interface.current_animation_frame++;
-		if (interface.current_animation_frame >= (TOTAL_ANIMATION_FRAMES - 1)) {
-			in_forward_progress = !in_forward_progress;
-		}
-	}
-	else {
-		interface.current_animation_frame--;
-		if (interface.current_animation_frame <= 0) {
-			in_forward_progress = !in_forward_progress;
-		}
-	}
-		      
-	gtk_widget_queue_draw (interface.drawing_area);
-
-	return TRUE;
-}
-
 void
 define_popt_descriptions (void) 
 {
@@ -1179,14 +1064,19 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 	if ((condition == G_IO_IN) || (condition == G_IO_IN + G_IO_HUP)) { 
 	
 		GError       *error = NULL;
+		GTimer       *timer;
 		GString      *string;
 		GdkRectangle prior_rect;
 		GdkRectangle after_rect;
+		gulong       duration;
 		gint	     look_in_folder_string_length;
 		
 		string = g_string_new (NULL);
 		look_in_folder_string_length = strlen (search_data->look_in_folder);
 
+		timer = g_timer_new();
+		g_timer_start (timer);
+
 		while (ioc->is_readable != TRUE);
 
 		do {
@@ -1208,12 +1098,13 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 				if (status == G_IO_STATUS_EOF) {
 					broken_pipe = TRUE;
 				}
-				
-				while (gtk_events_pending ()) {
-					if (search_data->running == MAKE_IT_QUIT) {
-						return FALSE;
+				else if (status == G_IO_STATUS_AGAIN) {
+					while (gtk_events_pending ()) {
+						if (search_data->running == MAKE_IT_QUIT) {
+							return FALSE;
+						}
+						gtk_main_iteration (); 				
 					}
-					gtk_main_iteration (); 				
 				}
 				
 			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
@@ -1268,26 +1159,32 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 			}
 			g_free (utf8);
 			g_free (filename);
-			
+
 			gtk_tree_view_get_visible_rect (GTK_TREE_VIEW(interface.tree), &prior_rect);
 			
-			while (gtk_events_pending ()) {
-				if (search_data->running == MAKE_IT_QUIT) {
-					return FALSE;
-				}
-				gtk_main_iteration (); 				
-			}
-			
 			if (prior_rect.y == 0) {
 				gtk_tree_view_get_visible_rect (GTK_TREE_VIEW(interface.tree), &after_rect);
 				if (after_rect.y <= 40) {  /* limit this hack to the first few pixels */
 					gtk_tree_view_scroll_to_point (GTK_TREE_VIEW(interface.tree), -1, 0);
+				}	
+			}
+
+			g_timer_elapsed (timer, &duration);
+
+			if (duration > GNOME_SEARCH_TOOL_REFRESH_DURATION) {
+				while (gtk_events_pending ()) {
+					if (search_data->running == MAKE_IT_QUIT) {
+						return FALSE;
+					}
+					gtk_main_iteration ();		
 				}
-			}	
+				g_timer_reset (timer);
+			}
 			
 		} while (g_io_channel_get_buffer_condition (ioc) == G_IO_IN);
 		
 		g_string_free (string, TRUE);
+		g_timer_destroy (timer);
 	}
 
 	if (condition != G_IO_IN || broken_pipe == TRUE) { 
@@ -1299,6 +1196,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		search_data->lock = FALSE;
 		search_data->running = NOT_RUNNING;
 		search_data->not_running_timeout = TRUE;
+		g_hash_table_destroy (search_data->pixbuf_hash);
 		g_timeout_add (500, not_running_timeout_cb, NULL);
 
 		update_search_counts ();
@@ -1351,14 +1249,15 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 				if (status == G_IO_STATUS_EOF) {
 					broken_pipe = TRUE;
 				}
-	
-				while (gtk_events_pending ()) {
-					if (search_data->running == MAKE_IT_QUIT) {
-						break;
+				else if (status == G_IO_STATUS_AGAIN) {
+					while (gtk_events_pending ()) {
+						if (search_data->running == MAKE_IT_QUIT) {
+							break;
+						}
+						gtk_main_iteration ();
 					}
-					gtk_main_iteration ();
 				}
-					
+				
 			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
 			
 			if (broken_pipe == TRUE) {
@@ -1487,6 +1386,7 @@ spawn_search_command (gchar *command)
 	search_command.lock = TRUE;
 	search_command.aborted = FALSE;
 	search_command.running = RUNNING; 
+	search_command.pixbuf_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
 	gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.stop_button);
 	gtk_widget_show (interface.stop_button);
@@ -1571,8 +1471,6 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 		{
 			add_atk_namedesc (GTK_WIDGET(entry), _("Search Rule Value Entry"), 
 					  _("Enter a value for search rule"));
-			add_atk_relation (entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
-			add_atk_relation (GTK_WIDGET(label), entry, ATK_RELATION_LABEL_FOR);
 		}
 		
 		gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (entry));
@@ -1679,7 +1577,6 @@ create_additional_constraint_section (void)
 	{
 		add_atk_namedesc (GTK_WIDGET (interface.constraint_menu), _("Search Rules Menu"), 
 				  _("Select a search rule from the menu"));
-		add_atk_relation (interface.constraint_menu, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
 	}
 
 	interface.add_button = gtk_button_new_from_stock (GTK_STOCK_ADD);
@@ -1875,29 +1772,24 @@ create_main_window (void)
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
-	interface.drawing_area = gtk_drawing_area_new ();
-	gtk_box_pack_start (GTK_BOX (vbox), interface.drawing_area, TRUE, FALSE, 0);
-
-	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area),
-	                       DEFAULT_ANIMATION_WIDTH,
-			       DEFAULT_ANIMATION_HEIGHT);
+	interface.spinner = gsearch_spinner_new ();
+	gtk_widget_show (interface.spinner);
+	gtk_box_pack_start (GTK_BOX (vbox), interface.spinner, FALSE, FALSE, 0);
+	gsearch_spinner_set_small_mode (GSEARCH_SPINNER (interface.spinner), FALSE);
 			  
-	gtk_drag_source_set (interface.drawing_area, 
+	gtk_drag_source_set (interface.spinner, 
 			     GDK_BUTTON1_MASK,
 			     drag_types, 
 			     G_N_ELEMENTS (drag_types), 
 			     GDK_ACTION_COPY);
 			     
-	gtk_drag_source_set_icon_stock (interface.drawing_area,
+	gtk_drag_source_set_icon_stock (interface.spinner,
 	                                GTK_STOCK_FIND);
 			  
-	g_signal_connect (G_OBJECT (interface.drawing_area), 
+	g_signal_connect (G_OBJECT (interface.spinner), 
 			  "drag_data_get",
 			  G_CALLBACK (drag_data_animation_cb), 
 			  interface.main_window);
-
-	g_signal_connect (interface.drawing_area, "expose-event",
-			  G_CALLBACK (animation_expose_event_cb), NULL);
 	
 	interface.table = gtk_table_new (2, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE(interface.table), 6);
@@ -1911,7 +1803,7 @@ create_main_window (void)
 	gtk_table_attach (GTK_TABLE(interface.table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 1);
 
 	interface.file_is_named_entry = gnome_entry_new ("gsearchtool-file-entry");
-	gtk_label_set_mnemonic_widget (GTK_LABEL(label), gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry)));
+	gtk_label_set_mnemonic_widget (GTK_LABEL(label), interface.file_is_named_entry);
 	gnome_entry_set_max_saved (GNOME_ENTRY(interface.file_is_named_entry), 10);
 	gtk_table_attach (GTK_TABLE(interface.table), interface.file_is_named_entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 	entry =  gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry));
@@ -1919,9 +1811,8 @@ create_main_window (void)
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(interface.file_is_named_entry)))
 	{
 		interface.is_gail_loaded = TRUE;
-		add_atk_namedesc (interface.file_is_named_entry, _("Name Contains Entry"), _("Enter the file name you want to search"));
+		add_atk_namedesc (interface.file_is_named_entry, NULL, _("Enter the file name you want to search"));
 		add_atk_namedesc (entry, _("Name Contains Entry"), _("Enter the file name you want to search"));
-		add_atk_relation (interface.file_is_named_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
 	}	
      
 	g_signal_connect (G_OBJECT (interface.file_is_named_entry), "activate",
@@ -1939,17 +1830,18 @@ create_main_window (void)
 	gtk_table_attach(GTK_TABLE(interface.table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 	
 	interface.look_in_folder_entry = gnome_file_entry_new ("gsearchtool-folder-entry", _("Browse"));
-	gnome_file_entry_set_directory_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry), TRUE);
+	gnome_file_entry_set_directory_entry (GNOME_FILE_ENTRY (interface.look_in_folder_entry), TRUE);
+	g_object_set (G_OBJECT (interface.look_in_folder_entry), "use-filechooser", TRUE, NULL);
+	
 	entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
-	gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL(label), interface.look_in_folder_entry);
 	folder_entry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
 	gtk_table_attach (GTK_TABLE(interface.table), interface.look_in_folder_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 	
 	if (interface.is_gail_loaded)
 	{ 
-		add_atk_namedesc (GTK_WIDGET(folder_entry), _("Look in Folder Entry"), _("Enter the folder name where you want to start the search"));
+		add_atk_namedesc (GTK_WIDGET(folder_entry), NULL, _("Enter the folder name where you want to start the search"));
 		add_atk_namedesc (GTK_WIDGET(entry), _("Look in Folder Entry"), _("Enter the folder name where you want to start the search"));
-		add_atk_relation (folder_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY); 
 	}
 	
 	g_signal_connect (G_OBJECT (entry), "key_press_event",
@@ -2039,7 +1931,7 @@ register_gsearchtool_icon (GtkIconFactory *factory)
 
 	source = gtk_icon_source_new ();
 
-	gtk_icon_source_set_filename (source, GNOME_ICONDIR"/"GNOME_SEARCH_TOOL_ICON);
+	gtk_icon_source_set_icon_name (source, GNOME_SEARCH_TOOL_ICON);
 
 	icon_set = gtk_icon_set_new ();
 	gtk_icon_set_add_source (icon_set, source);
@@ -2270,6 +2162,7 @@ main (int 	argc,
 	GnomeProgram *gsearchtool;
 	GnomeClient  *client;
 	GtkWidget    *window;
+	GtkIconInfo  *icon_info;
 
 	memset (&interface, 0, sizeof (interface));
 
@@ -2295,7 +2188,12 @@ main (int 	argc,
 					  GNOME_PARAM_APP_DATADIR, DATADIR,  
 					  NULL);
 	gsearchtool_init_stock_icons ();				  
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/"GNOME_SEARCH_TOOL_ICON);
+	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), GNOME_SEARCH_TOOL_ICON, 
+	                                        GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE, 0);
+	if (icon_info) {
+		gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+	}
 
 	if (!bonobo_init_full (&argc, argv, bonobo_activation_orb_get (), NULL, NULL))
 		g_error (_("Cannot initialize bonobo."));
@@ -2337,11 +2235,6 @@ main (int 	argc,
 	
 	gtk_widget_show (interface.main_window);
 	
-	interface.icon_theme = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (interface.icon_theme, TRUE);
-
-	setup_animation_image ();
-	
 	if (handle_popt_args () == FALSE) {
 		handle_gconf_settings (); 
 	}	
